@@ -1,12 +1,11 @@
 fn main() {
     eprintln!(
-        "You have to add `audio.mp3` to `soloud` directory  and modify this example to run it!!"
+        "You have to add `sample.wav` to `soloud` directory  and modify this example to run it!!"
     );
     // use soloud::*;
     // let sl = Soloud::default().unwrap();
     // let mut wav = audio::Wav::default();
-    // // Use weak reference because we know `'static &[u8]` lives longer than `Soloud`
-    // wav.load_mem_weak(include_bytes!("../audio.mp3")).unwrap();
+    // wav.load_mem(include_bytes!("../../sample.wav")).unwrap();
     // sl.play(&wav);
     // while sl.voice_count() > 0 {
     //     std::thread::sleep(std::time::Duration::from_millis(100));
