@@ -26,9 +26,7 @@ impl FlangerFilter {
     /// Set filter params
     pub fn set_params(&mut self, delay: f32, freq: f32) -> Result<(), SoloudError> {
         ffi_call!(soloud_sys::soloud::FlangerFilter_setParams(
-            self.inner,
-            delay,
-            freq
+            self.inner, delay, freq
         ))
     }
 }
